@@ -6,7 +6,7 @@ import copy
 
 import singer
 from singer import metrics, metadata, Transformer, utils
-from singer.utils import strptime_to_utc
+from singer.utils import strftime, strptime_to_utc
 
 from tap_ilevel.transform import transform_json, hash_data
 from tap_ilevel.streams import STREAMS
@@ -89,7 +89,8 @@ def process_records(result_records,
                 else:
                     max_bookmark_value = bookmark_dt
 
-                last_dttm = datetime.strptime(last_date, "%Y-%m-%d")
+                # Lookback window, always process last 14 days
+                last_dttm = datetime.strptime(last_date, "%Y-%m-%d") - timedelta(days=14)
 
                 # Keep only records whose bookmark is on after the last_date
                 if bookmark_dttm >= last_dttm:
@@ -282,7 +283,7 @@ def __process_incremental_stream(req_state):
 # Given a set of 'stanardized ids', reflecting attributes that have been updated for a given
 #  time window, perform any additional API requests (iGetBatch) to retrieve associated data,
 #  and publish results.
-def process_iget_batch_for_standardized_id_set(std_id_set, req_state, max_bookmark_value):
+def process_iget_batch_for_standardized_id_set(std_id_set, req_state, max_bookmark_value=None):
     update_count = 0
 
     #Retrieve additional details for id criteria.
@@ -347,8 +348,12 @@ def __process_standardized_data_stream(req_state):
         batch = 1
         for id_set in updated_object_id_sets:
             processed_record_count = 0
-            max_bookmark_value, processed_record_count = process_iget_batch_for_standardized_id_set(
-                id_set, req_state, max_bookmark_value)
+            temp_max_bookmark_value, processed_record_count = process_iget_batch_for_standardized_id_set(
+                id_set, req_state)
+            temp_max_bookmark_value_dttm = datetime.strptime(temp_max_bookmark_value, "%Y-%m-%d")
+            max_bookmark_value_dttm = datetime.strptime(max_bookmark_value, "%Y-%m-%d")
+            if temp_max_bookmark_value_dttm > max_bookmark_value_dttm:
+                max_bookmark_value = temp_max_bookmark_value
 
             LOGGER.info('periodic_data_standardized, {} - {}, Batch #{}, Requests: {}, Results: {}'.format(
                 cur_start_date, cur_end_date, batch, len(id_set), processed_record_count))
@@ -552,7 +557,12 @@ def __process_periodic_data_calcs(req_state, scenario_name='Actual', currency_co
                                     dimensions = {
                                         'data_item_id': data_item_id,
                                         'entity_id': entity_id,
-                                        'excel_formula': excel_formula
+                                        'scenario_id': scenario_id,
+                                        'period_type': period_type,
+                                        'end_of_period_value': end_of_period_value,
+                                        'currency_code': currency_code,
+                                        'exchange_rate_type': exchange_rate_type,
+                                        'data_value_type': data_value_type
                                     }
                                     hash_key = str(hash_data(json.dumps(dimensions, sort_keys=True)))
 
